# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/billing/v1alpha1/one_time_export_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.billing.v1alpha1 import one_time_export_pb2 as nebius_dot_billing_dot_v1alpha1_dot_one__time__export__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5nebius/billing/v1alpha1/one_time_export_service.proto\x12\x17nebius.billing.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a-nebius/billing/v1alpha1/one_time_export.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\"\xb9\x01\n\x1a\x43reateOneTimeExportRequest\x12S\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x13\xbaH\x03\xc8\x01\x01\xe2J\n\x12\x08\x63ontractR\x08metadata\x12\x46\n\x04spec\x18\x02 \x01(\x0b\x32*.nebius.billing.v1alpha1.OneTimeExportSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"N\n\x17GetOneTimeExportRequest\x12\x33\n\x02id\x18\x01 \x01(\tB#\xbaH\x03\xc8\x01\x01\xbaJ\x01\x03\xe2J\x16\n\x14\x62illingonetimeexportR\x02id\"\x89\x01\n\x19ListOneTimeExportsRequest\x12\x30\n\tparent_id\x18\x01 \x01(\tB\x13\xbaH\x03\xc8\x01\x01\xe2J\n\n\x08\x63ontractR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x82\x01\n\x1aListOneTimeExportsResponse\x12<\n\x05items\x18\x01 \x03(\x0b\x32&.nebius.billing.v1alpha1.OneTimeExportR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xf7\x02\n\x14OneTimeExportService\x12Z\n\x06\x43reate\x12\x33.nebius.billing.v1alpha1.CreateOneTimeExportRequest\x1a\x1b.nebius.common.v1.Operation\x12_\n\x03Get\x12\x30.nebius.billing.v1alpha1.GetOneTimeExportRequest\x1a&.nebius.billing.v1alpha1.OneTimeExport\x12o\n\x04List\x12\x32.nebius.billing.v1alpha1.ListOneTimeExportsRequest\x1a\x33.nebius.billing.v1alpha1.ListOneTimeExportsResponse\x1a\x31\xbaJ.api.billing-report-exporter.billing-data-planeBt\n\x1e\x61i.nebius.pub.billing.v1alpha1B\x19OneTimeExportServiceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.billing.v1alpha1.one_time_export_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.billing.v1alpha1B\031OneTimeExportServiceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1'
  _CREATEONETIMEEXPORTREQUEST.fields_by_name['metadata']._options = None
  _CREATEONETIMEEXPORTREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001\342J\n\022\010contract'
  _CREATEONETIMEEXPORTREQUEST.fields_by_name['spec']._options = None
  _CREATEONETIMEEXPORTREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _GETONETIMEEXPORTREQUEST.fields_by_name['id']._options = None
  _GETONETIMEEXPORTREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001\272J\001\003\342J\026\n\024billingonetimeexport'
  _LISTONETIMEEXPORTSREQUEST.fields_by_name['parent_id']._options = None
  _LISTONETIMEEXPORTSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001\342J\n\n\010contract'
  _ONETIMEEXPORTSERVICE._options = None
  _ONETIMEEXPORTSERVICE._serialized_options = b'\272J.api.billing-report-exporter.billing-data-plane'
  _globals['_CREATEONETIMEEXPORTREQUEST']._serialized_start=252
  _globals['_CREATEONETIMEEXPORTREQUEST']._serialized_end=437
  _globals['_GETONETIMEEXPORTREQUEST']._serialized_start=439
  _globals['_GETONETIMEEXPORTREQUEST']._serialized_end=517
  _globals['_LISTONETIMEEXPORTSREQUEST']._serialized_start=520
  _globals['_LISTONETIMEEXPORTSREQUEST']._serialized_end=657
  _globals['_LISTONETIMEEXPORTSRESPONSE']._serialized_start=660
  _globals['_LISTONETIMEEXPORTSRESPONSE']._serialized_end=790
  _globals['_ONETIMEEXPORTSERVICE']._serialized_start=793
  _globals['_ONETIMEEXPORTSERVICE']._serialized_end=1168
# @@protoc_insertion_point(module_scope)
