# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/capacity/v1/capacity_block_group.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.capacity.v1 import resource_affinity_pb2 as nebius_dot_capacity_dot_v1_dot_resource__affinity__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-nebius/capacity/v1/capacity_block_group.proto\x12\x12nebius.capacity.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a*nebius/capacity/v1/resource_affinity.proto\x1a\x1fnebius/common/v1/metadata.proto\"\x18\n\x16\x43\x61pacityBlockGroupSpec\"\xce\x02\n\x19\x43urrentContinuousInterval\x12\x39\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x1a\n\x08quantity\x18\x03 \x01(\x04R\x08quantity\x12I\n\x05state\x18\x04 \x01(\x0e\x32\x33.nebius.capacity.v1.CurrentContinuousInterval.StateR\x05state\"X\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_SCHEDULED\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x11\n\rSTATE_EXPIRED\x10\x03\"\x9e\x07\n\x18\x43\x61pacityBlockGroupStatus\x12\x16\n\x06region\x18\x01 \x01(\tR\x06region\x12Q\n\x11resource_affinity\x18\x02 \x01(\x0b\x32$.nebius.capacity.v1.ResourceAffinityR\x10resourceAffinity\x12\x18\n\x07service\x18\x03 \x01(\tR\x07service\x12H\n\x05state\x18\x05 \x01(\x0e\x32\x32.nebius.capacity.v1.CapacityBlockGroupStatus.StateR\x05state\x12#\n\rcurrent_limit\x18\x06 \x01(\x04R\x0c\x63urrentLimit\x12\x14\n\x05usage\x18\x08 \x01(\x04R\x05usage\x12)\n\x10usage_percentage\x18\t \x01(\tR\x0fusagePercentage\x12@\n\x0enext_change_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cnextChangeAt\x12)\n\x0enext_change_to\x18\x0b \x01(\x04H\x00R\x0cnextChangeTo\x88\x01\x01\x12m\n\x1b\x63urrent_continuous_interval\x18\x0c \x01(\x0b\x32-.nebius.capacity.v1.CurrentContinuousIntervalR\x19\x63urrentContinuousInterval\x12X\n\x0busage_state\x18\r \x01(\x0e\x32\x37.nebius.capacity.v1.CapacityBlockGroupStatus.UsageStateR\nusageState\x12 \n\x0breconciling\x18\x64 \x01(\x08R\x0breconciling\"n\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x14\n\x10STATE_ALLOCATING\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x12\n\x0eSTATE_SHUTTING\x10\x03\x12\x12\n\x0eSTATE_INACTIVE\x10\x04\"r\n\nUsageState\x12\x1b\n\x17USAGE_STATE_UNSPECIFIED\x10\x00\x12\x14\n\x10USAGE_STATE_USED\x10\x01\x12\x18\n\x14USAGE_STATE_NOT_USED\x10\x02\x12\x17\n\x13USAGE_STATE_UNKNOWN\x10\x03\x42\x11\n\x0f_next_change_to\"\xf9\x01\n\x12\x43\x61pacityBlockGroup\x12Q\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x11\xbaH\x03\xc8\x01\x01\xe2J\x08\x12\x06tenantR\x08metadata\x12>\n\x04spec\x18\x02 \x01(\x0b\x32*.nebius.capacity.v1.CapacityBlockGroupSpecR\x04spec\x12J\n\x06status\x18\x03 \x01(\x0b\x32,.nebius.capacity.v1.CapacityBlockGroupStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\x42h\n\x19\x61i.nebius.pub.capacity.v1B\x17\x43\x61pacityBlockGroupProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/capacity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.capacity.v1.capacity_block_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.capacity.v1B\027CapacityBlockGroupProtoP\001Z0github.com/nebius/gosdk/proto/nebius/capacity/v1'
  _CAPACITYBLOCKGROUP.fields_by_name['metadata']._options = None
  _CAPACITYBLOCKGROUP.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001\342J\010\022\006tenant'
  _CAPACITYBLOCKGROUP.fields_by_name['status']._options = None
  _CAPACITYBLOCKGROUP.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _CAPACITYBLOCKGROUP._options = None
  _CAPACITYBLOCKGROUP._serialized_options = b'\272J\001\002'
  _globals['_CAPACITYBLOCKGROUPSPEC']._serialized_start=234
  _globals['_CAPACITYBLOCKGROUPSPEC']._serialized_end=258
  _globals['_CURRENTCONTINUOUSINTERVAL']._serialized_start=261
  _globals['_CURRENTCONTINUOUSINTERVAL']._serialized_end=595
  _globals['_CURRENTCONTINUOUSINTERVAL_STATE']._serialized_start=507
  _globals['_CURRENTCONTINUOUSINTERVAL_STATE']._serialized_end=595
  _globals['_CAPACITYBLOCKGROUPSTATUS']._serialized_start=598
  _globals['_CAPACITYBLOCKGROUPSTATUS']._serialized_end=1524
  _globals['_CAPACITYBLOCKGROUPSTATUS_STATE']._serialized_start=1279
  _globals['_CAPACITYBLOCKGROUPSTATUS_STATE']._serialized_end=1389
  _globals['_CAPACITYBLOCKGROUPSTATUS_USAGESTATE']._serialized_start=1391
  _globals['_CAPACITYBLOCKGROUPSTATUS_USAGESTATE']._serialized_end=1505
  _globals['_CAPACITYBLOCKGROUP']._serialized_start=1527
  _globals['_CAPACITYBLOCKGROUP']._serialized_end=1776
# @@protoc_insertion_point(module_scope)
