# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/billing/v1alpha1/one_time_export.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.billing.v1alpha1 import billing_report_exporter_pb2 as nebius_dot_billing_dot_v1alpha1_dot_billing__report__exporter__pb2
from nebius.api.nebius.common.v1 import error_pb2 as nebius_dot_common_dot_v1_dot_error__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-nebius/billing/v1alpha1/one_time_export.proto\x12\x17nebius.billing.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a\x35nebius/billing/v1alpha1/billing_report_exporter.proto\x1a\x1cnebius/common/v1/error.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xfe\x01\n\rOneTimeExport\x12S\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x13\xbaH\x03\xc8\x01\x01\xe2J\n\x12\x08\x63ontractR\x08metadata\x12\x46\n\x04spec\x18\x02 \x01(\x0b\x32*.nebius.billing.v1alpha1.OneTimeExportSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12J\n\x06status\x18\x03 \x01(\x0b\x32,.nebius.billing.v1alpha1.OneTimeExportStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"\xac\x01\n\x11OneTimeExportSpec\x12\x45\n\x06\x66ormat\x18\x01 \x01(\x0e\x32%.nebius.billing.v1alpha1.ExportFormatB\x06\xbaH\x03\xc8\x01\x01R\x06\x66ormat\x12)\n\x0cstart_period\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0bstartPeriod\x12%\n\nend_period\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tendPeriod\"\x94\x02\n\x13OneTimeExportStatus\x12\x41\n\x05state\x18\x01 \x01(\x0e\x32+.nebius.billing.v1alpha1.OneTimeExportStateR\x05state\x12&\n\x0c\x64ownload_url\x18\x02 \x01(\tB\x03\xc0J\x01R\x0b\x64ownloadUrl\x12\x39\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12W\n\rstate_details\x18\x04 \x01(\x0b\x32\x32.nebius.billing.v1alpha1.OneTimeExportStateDetailsR\x0cstateDetails\"Q\n\x19OneTimeExportStateDetails\x12\x34\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1e.nebius.common.v1.ServiceErrorR\x05\x65rror*\xec\x01\n\x12OneTimeExportState\x12%\n!ONE_TIME_EXPORT_STATE_UNSPECIFIED\x10\x00\x12#\n\x1fONE_TIME_EXPORT_STATE_SCHEDULED\x10\x01\x12!\n\x1dONE_TIME_EXPORT_STATE_RUNNING\x10\x02\x12!\n\x1dONE_TIME_EXPORT_STATE_SUCCESS\x10\x03\x12 \n\x1cONE_TIME_EXPORT_STATE_FAILED\x10\x04\x12\"\n\x1eONE_TIME_EXPORT_STATE_ARCHIVED\x10\x05\x42m\n\x1e\x61i.nebius.pub.billing.v1alpha1B\x12OneTimeExportProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.billing.v1alpha1.one_time_export_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.billing.v1alpha1B\022OneTimeExportProtoP\001Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1'
  _ONETIMEEXPORT.fields_by_name['metadata']._options = None
  _ONETIMEEXPORT.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001\342J\n\022\010contract'
  _ONETIMEEXPORT.fields_by_name['spec']._options = None
  _ONETIMEEXPORT.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _ONETIMEEXPORT.fields_by_name['status']._options = None
  _ONETIMEEXPORT.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _ONETIMEEXPORT._options = None
  _ONETIMEEXPORT._serialized_options = b'\272J\001\002'
  _ONETIMEEXPORTSPEC.fields_by_name['format']._options = None
  _ONETIMEEXPORTSPEC.fields_by_name['format']._serialized_options = b'\272H\003\310\001\001'
  _ONETIMEEXPORTSPEC.fields_by_name['start_period']._options = None
  _ONETIMEEXPORTSPEC.fields_by_name['start_period']._serialized_options = b'\272H\003\310\001\001'
  _ONETIMEEXPORTSPEC.fields_by_name['end_period']._options = None
  _ONETIMEEXPORTSPEC.fields_by_name['end_period']._serialized_options = b'\272H\003\310\001\001'
  _ONETIMEEXPORTSTATUS.fields_by_name['download_url']._options = None
  _ONETIMEEXPORTSTATUS.fields_by_name['download_url']._serialized_options = b'\300J\001'
  _globals['_ONETIMEEXPORTSTATE']._serialized_start=1075
  _globals['_ONETIMEEXPORTSTATE']._serialized_end=1311
  _globals['_ONETIMEEXPORT']._serialized_start=281
  _globals['_ONETIMEEXPORT']._serialized_end=535
  _globals['_ONETIMEEXPORTSPEC']._serialized_start=538
  _globals['_ONETIMEEXPORTSPEC']._serialized_end=710
  _globals['_ONETIMEEXPORTSTATUS']._serialized_start=713
  _globals['_ONETIMEEXPORTSTATUS']._serialized_end=989
  _globals['_ONETIMEEXPORTSTATEDETAILS']._serialized_start=991
  _globals['_ONETIMEEXPORTSTATEDETAILS']._serialized_end=1072
# @@protoc_insertion_point(module_scope)
