# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/capacity/v1/resource_advice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/capacity/v1/resource_advice.proto\x12\x12nebius.capacity.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xf5\x01\n\x0eResourceAdvice\x12Q\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x11\xbaH\x03\xc8\x01\x01\xe2J\x08\x12\x06tenantR\x08metadata\x12\x42\n\x04spec\x18\x02 \x01(\x0b\x32&.nebius.capacity.v1.ResourceAdviceSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32(.nebius.capacity.v1.ResourceAdviceStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"\xbd\x01\n\x12ResourceAdviceSpec\x12\x1c\n\x06region\x18\x01 \x01(\tB\x04\xbaJ\x01\x02R\x06region\x12\x1c\n\x06\x66\x61\x62ric\x18\x02 \x01(\tB\x04\xbaJ\x01\x02R\x06\x66\x61\x62ric\x12W\n\x10\x63ompute_instance\x18\n \x01(\x0b\x32*.nebius.capacity.v1.ComputeInstanceDetailsH\x00R\x0f\x63omputeInstanceB\x12\n\x10resource_details\"\xab\x03\n\x16\x43omputeInstanceDetails\x12 \n\x08platform\x18\x01 \x01(\tB\x04\xbaJ\x01\x02R\x08platform\x12O\n\x06preset\x18\x02 \x01(\x0b\x32\x31.nebius.capacity.v1.ComputeInstanceDetails.PresetB\x04\xbaJ\x01\x02R\x06preset\x12\x30\n\x14gpu_memory_gigabytes\x18\x03 \x01(\x05R\x12gpuMemoryGigabytes\x1a\xeb\x01\n\x06Preset\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12Y\n\tresources\x18\x02 \x01(\x0b\x32;.nebius.capacity.v1.ComputeInstanceDetails.Preset.ResourcesR\tresources\x1ar\n\tResources\x12\x1d\n\nvcpu_count\x18\x01 \x01(\x05R\tvcpuCount\x12)\n\x10memory_gibibytes\x18\x02 \x01(\x05R\x0fmemoryGibibytes\x12\x1b\n\tgpu_count\x18\x03 \x01(\x05R\x08gpuCount\"\xe7\x04\n\x14ResourceAdviceStatus\x12Q\n\x08reserved\x18\x01 \x01(\x0b\x32\x35.nebius.capacity.v1.ResourceAdviceStatus.AvailabilityR\x08reserved\x12R\n\ton_demand\x18\x02 \x01(\x0b\x32\x35.nebius.capacity.v1.ResourceAdviceStatus.AvailabilityR\x08onDemand\x12W\n\x0bpreemptible\x18\x03 \x01(\x0b\x32\x35.nebius.capacity.v1.ResourceAdviceStatus.AvailabilityR\x0bpreemptible\x1a\xce\x02\n\x0c\x41vailability\x12^\n\ndata_state\x18\x01 \x01(\x0e\x32?.nebius.capacity.v1.ResourceAdviceStatus.Availability.DataStateR\tdataState\x12\x1c\n\tavailable\x18\x02 \x01(\rR\tavailable\x12\x14\n\x05limit\x18\x04 \x01(\rR\x05limit\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\"k\n\tDataState\x12\x1a\n\x16\x44\x41TA_STATE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x44\x41TA_STATE_FRESH\x10\x01\x12\x14\n\x10\x44\x41TA_STATE_STALE\x10\x02\x12\x16\n\x12\x44\x41TA_STATE_UNKNOWN\x10\nBd\n\x19\x61i.nebius.pub.capacity.v1B\x13ResourceAdviceProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/capacity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.capacity.v1.resource_advice_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.capacity.v1B\023ResourceAdviceProtoP\001Z0github.com/nebius/gosdk/proto/nebius/capacity/v1'
  _RESOURCEADVICE.fields_by_name['metadata']._options = None
  _RESOURCEADVICE.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001\342J\010\022\006tenant'
  _RESOURCEADVICE.fields_by_name['spec']._options = None
  _RESOURCEADVICE.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCEADVICE.fields_by_name['status']._options = None
  _RESOURCEADVICE.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _RESOURCEADVICE._options = None
  _RESOURCEADVICE._serialized_options = b'\272J\001\002'
  _RESOURCEADVICESPEC.fields_by_name['region']._options = None
  _RESOURCEADVICESPEC.fields_by_name['region']._serialized_options = b'\272J\001\002'
  _RESOURCEADVICESPEC.fields_by_name['fabric']._options = None
  _RESOURCEADVICESPEC.fields_by_name['fabric']._serialized_options = b'\272J\001\002'
  _COMPUTEINSTANCEDETAILS.fields_by_name['platform']._options = None
  _COMPUTEINSTANCEDETAILS.fields_by_name['platform']._serialized_options = b'\272J\001\002'
  _COMPUTEINSTANCEDETAILS.fields_by_name['preset']._options = None
  _COMPUTEINSTANCEDETAILS.fields_by_name['preset']._serialized_options = b'\272J\001\002'
  _globals['_RESOURCEADVICE']._serialized_start=186
  _globals['_RESOURCEADVICE']._serialized_end=431
  _globals['_RESOURCEADVICESPEC']._serialized_start=434
  _globals['_RESOURCEADVICESPEC']._serialized_end=623
  _globals['_COMPUTEINSTANCEDETAILS']._serialized_start=626
  _globals['_COMPUTEINSTANCEDETAILS']._serialized_end=1053
  _globals['_COMPUTEINSTANCEDETAILS_PRESET']._serialized_start=818
  _globals['_COMPUTEINSTANCEDETAILS_PRESET']._serialized_end=1053
  _globals['_COMPUTEINSTANCEDETAILS_PRESET_RESOURCES']._serialized_start=939
  _globals['_COMPUTEINSTANCEDETAILS_PRESET_RESOURCES']._serialized_end=1053
  _globals['_RESOURCEADVICESTATUS']._serialized_start=1056
  _globals['_RESOURCEADVICESTATUS']._serialized_end=1671
  _globals['_RESOURCEADVICESTATUS_AVAILABILITY']._serialized_start=1337
  _globals['_RESOURCEADVICESTATUS_AVAILABILITY']._serialized_end=1671
  _globals['_RESOURCEADVICESTATUS_AVAILABILITY_DATASTATE']._serialized_start=1564
  _globals['_RESOURCEADVICESTATUS_AVAILABILITY_DATASTATE']._serialized_end=1671
# @@protoc_insertion_point(module_scope)
