# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/capacity/v1/resource_advice_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.capacity.v1 import resource_advice_pb2 as nebius_dot_capacity_dot_v1_dot_resource__advice__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0nebius/capacity/v1/resource_advice_service.proto\x12\x12nebius.capacity.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a(nebius/capacity/v1/resource_advice.proto\"\x87\x01\n\x19ListResourceAdviceRequest\x12.\n\tparent_id\x18\x01 \x01(\tB\x11\xbaH\x03\xc8\x01\x01\xe2J\x08\n\x06tenantR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"~\n\x1aListResourceAdviceResponse\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32\".nebius.capacity.v1.ResourceAdviceR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x9f\x01\n\x15ResourceAdviceService\x12\x65\n\x04List\x12-.nebius.capacity.v1.ListResourceAdviceRequest\x1a..nebius.capacity.v1.ListResourceAdviceResponse\x1a\x1f\xbaJ\x1c\x63\x61pacity-advisor.billing-cplBk\n\x19\x61i.nebius.pub.capacity.v1B\x1aResourceAdviceServiceProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/capacity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.capacity.v1.resource_advice_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.capacity.v1B\032ResourceAdviceServiceProtoP\001Z0github.com/nebius/gosdk/proto/nebius/capacity/v1'
  _LISTRESOURCEADVICEREQUEST.fields_by_name['parent_id']._options = None
  _LISTRESOURCEADVICEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001\342J\010\n\006tenant'
  _RESOURCEADVICESERVICE._options = None
  _RESOURCEADVICESERVICE._serialized_options = b'\272J\034capacity-advisor.billing-cpl'
  _globals['_LISTRESOURCEADVICEREQUEST']._serialized_start=170
  _globals['_LISTRESOURCEADVICEREQUEST']._serialized_end=305
  _globals['_LISTRESOURCEADVICERESPONSE']._serialized_start=307
  _globals['_LISTRESOURCEADVICERESPONSE']._serialized_end=433
  _globals['_RESOURCEADVICESERVICE']._serialized_start=436
  _globals['_RESOURCEADVICESERVICE']._serialized_end=595
# @@protoc_insertion_point(module_scope)
