# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/capacity/v1/capacity_block_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.capacity.v1 import capacity_block_group_pb2 as nebius_dot_capacity_dot_v1_dot_capacity__block__group__pb2
from nebius.api.nebius.capacity.v1 import resource_affinity_pb2 as nebius_dot_capacity_dot_v1_dot_resource__affinity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5nebius/capacity/v1/capacity_block_group_service.proto\x12\x12nebius.capacity.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a-nebius/capacity/v1/capacity_block_group.proto\x1a*nebius/capacity/v1/resource_affinity.proto\"Q\n\x1cGetCapacityBlockGroupRequest\x12\x31\n\x02id\x18\x01 \x01(\tB!\xbaH\x03\xc8\x01\x01\xbaJ\x01\x03\xe2J\x14\n\x12\x63\x61pacityblockgroupR\x02id\"\xdb\x01\n.GetCapacityBlockGroupByResourceAffinityRequest\x12.\n\tparent_id\x18\x01 \x01(\tB\x11\xbaH\x03\xc8\x01\x01\xe2J\x08\n\x06tenantR\x08parentId\x12\x1e\n\x06region\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06region\x12Y\n\x11resource_affinity\x18\x03 \x01(\x0b\x32$.nebius.capacity.v1.ResourceAffinityB\x06\xbaH\x03\xc8\x01\x01R\x10resourceAffinity\"\x98\x01\n\x1eListCapacityBlockGroupsRequest\x12.\n\tparent_id\x18\x01 \x01(\tB\x11\xbaH\x03\xc8\x01\x01\xe2J\x08\n\x06tenantR\x08parentId\x12\'\n\tpage_size\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\xc8\x01(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x87\x01\n\x1fListCapacityBlockGroupsResponse\x12<\n\x05items\x18\x01 \x03(\x0b\x32&.nebius.capacity.v1.CapacityBlockGroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"[\n&ListCapacityBlockGroupResourcesRequest\x12\x31\n\x02id\x18\x01 \x01(\tB!\xbaH\x03\xc8\x01\x01\xbaJ\x01\x03\xe2J\x14\n\x12\x63\x61pacityblockgroupR\x02id\"L\n\'ListCapacityBlockGroupResourcesResponse\x12!\n\x0cresource_ids\x18\x01 \x03(\tR\x0bresourceIds2\x9e\x04\n\x19\x43\x61pacityBlockGroupService\x12_\n\x03Get\x12\x30.nebius.capacity.v1.GetCapacityBlockGroupRequest\x1a&.nebius.capacity.v1.CapacityBlockGroup\x12\x83\x01\n\x15GetByResourceAffinity\x12\x42.nebius.capacity.v1.GetCapacityBlockGroupByResourceAffinityRequest\x1a&.nebius.capacity.v1.CapacityBlockGroup\x12o\n\x04List\x12\x32.nebius.capacity.v1.ListCapacityBlockGroupsRequest\x1a\x33.nebius.capacity.v1.ListCapacityBlockGroupsResponse\x12\x88\x01\n\rListResources\x12:.nebius.capacity.v1.ListCapacityBlockGroupResourcesRequest\x1a;.nebius.capacity.v1.ListCapacityBlockGroupResourcesResponse\x1a\x1e\xbaJ\x1b\x63\x61pacity-blocks.billing-cplBo\n\x19\x61i.nebius.pub.capacity.v1B\x1e\x43\x61pacityBlockGroupServiceProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/capacity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.capacity.v1.capacity_block_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.capacity.v1B\036CapacityBlockGroupServiceProtoP\001Z0github.com/nebius/gosdk/proto/nebius/capacity/v1'
  _GETCAPACITYBLOCKGROUPREQUEST.fields_by_name['id']._options = None
  _GETCAPACITYBLOCKGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001\272J\001\003\342J\024\n\022capacityblockgroup'
  _GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST.fields_by_name['parent_id']._options = None
  _GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001\342J\010\n\006tenant'
  _GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST.fields_by_name['region']._options = None
  _GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST.fields_by_name['region']._serialized_options = b'\272H\003\310\001\001'
  _GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST.fields_by_name['resource_affinity']._options = None
  _GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST.fields_by_name['resource_affinity']._serialized_options = b'\272H\003\310\001\001'
  _LISTCAPACITYBLOCKGROUPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTCAPACITYBLOCKGROUPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001\342J\010\n\006tenant'
  _LISTCAPACITYBLOCKGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTCAPACITYBLOCKGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\007\"\005\030\310\001(\000'
  _LISTCAPACITYBLOCKGROUPRESOURCESREQUEST.fields_by_name['id']._options = None
  _LISTCAPACITYBLOCKGROUPRESOURCESREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001\272J\001\003\342J\024\n\022capacityblockgroup'
  _CAPACITYBLOCKGROUPSERVICE._options = None
  _CAPACITYBLOCKGROUPSERVICE._serialized_options = b'\272J\033capacity-blocks.billing-cpl'
  _globals['_GETCAPACITYBLOCKGROUPREQUEST']._serialized_start=223
  _globals['_GETCAPACITYBLOCKGROUPREQUEST']._serialized_end=304
  _globals['_GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST']._serialized_start=307
  _globals['_GETCAPACITYBLOCKGROUPBYRESOURCEAFFINITYREQUEST']._serialized_end=526
  _globals['_LISTCAPACITYBLOCKGROUPSREQUEST']._serialized_start=529
  _globals['_LISTCAPACITYBLOCKGROUPSREQUEST']._serialized_end=681
  _globals['_LISTCAPACITYBLOCKGROUPSRESPONSE']._serialized_start=684
  _globals['_LISTCAPACITYBLOCKGROUPSRESPONSE']._serialized_end=819
  _globals['_LISTCAPACITYBLOCKGROUPRESOURCESREQUEST']._serialized_start=821
  _globals['_LISTCAPACITYBLOCKGROUPRESOURCESREQUEST']._serialized_end=912
  _globals['_LISTCAPACITYBLOCKGROUPRESOURCESRESPONSE']._serialized_start=914
  _globals['_LISTCAPACITYBLOCKGROUPRESOURCESRESPONSE']._serialized_end=990
  _globals['_CAPACITYBLOCKGROUPSERVICE']._serialized_start=993
  _globals['_CAPACITYBLOCKGROUPSERVICE']._serialized_end=1535
# @@protoc_insertion_point(module_scope)
