# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/security_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import security_group_pb2 as nebius_dot_vpc_dot_v1_dot_security__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*nebius/vpc/v1/security_group_service.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\"nebius/vpc/v1/security_group.proto\"F\n\x17GetSecurityGroupRequest\x12+\n\x02id\x18\x01 \x01(\tB\x1b\xbaH\x03\xc8\x01\x01\xe2J\x12\n\x10vpcsecuritygroupR\x02id\"l\n\x1dGetSecurityGroupByNameRequest\x12/\n\tparent_id\x18\x01 \x01(\tB\x12\xbaH\x03\xc8\x01\x01\xe2J\t\n\x07projectR\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x88\x01\n\x19ListSecurityGroupsRequest\x12/\n\tparent_id\x18\x01 \x01(\tB\x12\xbaH\x03\xc8\x01\x01\xe2J\t\n\x07projectR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x96\x01\n\"ListSecurityGroupsByNetworkRequest\x12\x34\n\nnetwork_id\x18\x01 \x01(\tB\x15\xbaH\x03\xc8\x01\x01\xe2J\x0c\n\nvpcnetworkR\tnetworkId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"x\n\x1aListSecurityGroupsResponse\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32\x1c.nebius.vpc.v1.SecurityGroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xf3\x02\n\x1a\x43reateSecurityGroupRequest\x12\x96\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xd5\x01\xbaH\xc5\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\xc8\x01\x01\xe2J\t\x12\x07projectR\x08metadata\x12<\n\x04spec\x18\x02 \x01(\x0b\x32 .nebius.vpc.v1.SecurityGroupSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xe8\x02\n\x1aUpdateSecurityGroupRequest\x12\x93\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xd2\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\xe2J\t\x12\x07projectR\x08metadata\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32 .nebius.vpc.v1.SecurityGroupSpecR\x04spec\"I\n\x1a\x44\x65leteSecurityGroupRequest\x12+\n\x02id\x18\x01 \x01(\tB\x1b\xbaH\x03\xc8\x01\x01\xe2J\x12\n\x10vpcsecuritygroupR\x02id2\x86\x05\n\x14SecurityGroupService\x12K\n\x03Get\x12&.nebius.vpc.v1.GetSecurityGroupRequest\x1a\x1c.nebius.vpc.v1.SecurityGroup\x12W\n\tGetByName\x12,.nebius.vpc.v1.GetSecurityGroupByNameRequest\x1a\x1c.nebius.vpc.v1.SecurityGroup\x12[\n\x04List\x12(.nebius.vpc.v1.ListSecurityGroupsRequest\x1a).nebius.vpc.v1.ListSecurityGroupsResponse\x12m\n\rListByNetwork\x12\x31.nebius.vpc.v1.ListSecurityGroupsByNetworkRequest\x1a).nebius.vpc.v1.ListSecurityGroupsResponse\x12P\n\x06\x43reate\x12).nebius.vpc.v1.CreateSecurityGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12P\n\x06Update\x12).nebius.vpc.v1.UpdateSecurityGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12P\n\x06\x44\x65lete\x12).nebius.vpc.v1.DeleteSecurityGroupRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x06\xbaJ\x03vpcB`\n\x14\x61i.nebius.pub.vpc.v1B\x19SecurityGroupServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.security_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\031SecurityGroupServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _GETSECURITYGROUPREQUEST.fields_by_name['id']._options = None
  _GETSECURITYGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001\342J\022\n\020vpcsecuritygroup'
  _GETSECURITYGROUPBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETSECURITYGROUPBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001\342J\t\n\007project'
  _GETSECURITYGROUPBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETSECURITYGROUPBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTSECURITYGROUPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTSECURITYGROUPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001\342J\t\n\007project'
  _LISTSECURITYGROUPSBYNETWORKREQUEST.fields_by_name['network_id']._options = None
  _LISTSECURITYGROUPSBYNETWORKREQUEST.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001\342J\014\n\nvpcnetwork'
  _CREATESECURITYGROUPREQUEST.fields_by_name['metadata']._options = None
  _CREATESECURITYGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\305\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\310\001\001\342J\t\022\007project'
  _CREATESECURITYGROUPREQUEST.fields_by_name['spec']._options = None
  _CREATESECURITYGROUPREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _UPDATESECURITYGROUPREQUEST.fields_by_name['metadata']._options = None
  _UPDATESECURITYGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\342J\t\022\007project'
  _DELETESECURITYGROUPREQUEST.fields_by_name['id']._options = None
  _DELETESECURITYGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001\342J\022\n\020vpcsecuritygroup'
  _SECURITYGROUPSERVICE._options = None
  _SECURITYGROUPSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETSECURITYGROUPREQUEST']._serialized_start=219
  _globals['_GETSECURITYGROUPREQUEST']._serialized_end=289
  _globals['_GETSECURITYGROUPBYNAMEREQUEST']._serialized_start=291
  _globals['_GETSECURITYGROUPBYNAMEREQUEST']._serialized_end=399
  _globals['_LISTSECURITYGROUPSREQUEST']._serialized_start=402
  _globals['_LISTSECURITYGROUPSREQUEST']._serialized_end=538
  _globals['_LISTSECURITYGROUPSBYNETWORKREQUEST']._serialized_start=541
  _globals['_LISTSECURITYGROUPSBYNETWORKREQUEST']._serialized_end=691
  _globals['_LISTSECURITYGROUPSRESPONSE']._serialized_start=693
  _globals['_LISTSECURITYGROUPSRESPONSE']._serialized_end=813
  _globals['_CREATESECURITYGROUPREQUEST']._serialized_start=816
  _globals['_CREATESECURITYGROUPREQUEST']._serialized_end=1187
  _globals['_UPDATESECURITYGROUPREQUEST']._serialized_start=1190
  _globals['_UPDATESECURITYGROUPREQUEST']._serialized_end=1550
  _globals['_DELETESECURITYGROUPREQUEST']._serialized_start=1552
  _globals['_DELETESECURITYGROUPREQUEST']._serialized_end=1625
  _globals['_SECURITYGROUPSERVICE']._serialized_start=1628
  _globals['_SECURITYGROUPSERVICE']._serialized_end=2274
# @@protoc_insertion_point(module_scope)
