# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/storage/v1/cors.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cnebius/storage/v1/cors.proto\x12\x11nebius.storage.v1\x1a\x1b\x62uf/validate/validate.proto\"P\n\x11\x43ORSConfiguration\x12;\n\x05rules\x18\x01 \x03(\x0b\x32\x1b.nebius.storage.v1.CORSRuleB\x08\xbaH\x05\x92\x01\x02\x10\x64R\x05rules\"\x99\x02\n\x08\x43ORSRule\x12\x13\n\x02id\x18\x01 \x01(\tH\x00R\x02id\x88\x01\x01\x12\'\n\x0f\x61llowed_headers\x18\x02 \x03(\tR\x0e\x61llowedHeaders\x12/\n\x0f\x61llowed_origins\x18\x03 \x03(\tB\x06\xbaH\x03\xc8\x01\x01R\x0e\x61llowedOrigins\x12/\n\x0f\x61llowed_methods\x18\x04 \x03(\tB\x06\xbaH\x03\xc8\x01\x01R\x0e\x61llowedMethods\x12%\n\x0e\x65xpose_headers\x18\x05 \x03(\tR\rexposeHeaders\x12+\n\x0fmax_age_seconds\x18\x06 \x01(\x05H\x01R\rmaxAgeSeconds\x88\x01\x01\x42\x05\n\x03_idB\x12\n\x10_max_age_secondsBX\n\x18\x61i.nebius.pub.storage.v1B\tCorsProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/storage/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.storage.v1.cors_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.storage.v1B\tCorsProtoP\001Z/github.com/nebius/gosdk/proto/nebius/storage/v1'
  _CORSCONFIGURATION.fields_by_name['rules']._options = None
  _CORSCONFIGURATION.fields_by_name['rules']._serialized_options = b'\272H\005\222\001\002\020d'
  _CORSRULE.fields_by_name['allowed_origins']._options = None
  _CORSRULE.fields_by_name['allowed_origins']._serialized_options = b'\272H\003\310\001\001'
  _CORSRULE.fields_by_name['allowed_methods']._options = None
  _CORSRULE.fields_by_name['allowed_methods']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CORSCONFIGURATION']._serialized_start=80
  _globals['_CORSCONFIGURATION']._serialized_end=160
  _globals['_CORSRULE']._serialized_start=163
  _globals['_CORSRULE']._serialized_end=444
# @@protoc_insertion_point(module_scope)
