# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/common/v1/warning.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/common/v1/warning.proto\x12\x10nebius.common.v1\"A\n\x08Warnings\x12\x35\n\x08warnings\x18\x01 \x03(\x0b\x32\x19.nebius.common.v1.WarningR\x08warnings\"\xd7\x04\n\x07Warning\x12\x38\n\x06target\x18\x01 \x01(\x0e\x32 .nebius.common.v1.Warning.TargetR\x06target\x12\x32\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x1e.nebius.common.v1.Warning.CodeR\x04\x63ode\x12\x18\n\x07summary\x18\x03 \x01(\tR\x07summary\x12)\n\x10summary_fallback\x18\x04 \x01(\tR\x0fsummaryFallback\x12\x18\n\x07\x64\x65tails\x18\x05 \x01(\tR\x07\x64\x65tails\x12)\n\x10\x64\x65tails_fallback\x18\x06 \x01(\tR\x0f\x64\x65tailsFallback\x12\x12\n\x04path\x18\x07 \x01(\tR\x04path\"S\n\x06Target\x12\x16\n\x12TARGET_UNSPECIFIED\x10\x00\x12\x0e\n\nTARGET_CLI\x10\x01\x12\r\n\tTARGET_TF\x10\x02\x12\x12\n\x0eTARGET_CONSOLE\x10\x03\"\xea\x01\n\x04\x43ode\x12\x14\n\x10\x43ODE_UNSPECIFIED\x10\x00\x12 \n\x1c\x43ODE_REGION_ROUTING_FAILOVER\x10\x01\x12 \n\x1c\x43ODE_DEPRECATED_TOOL_VERSION\x10\x02\x12\x1c\n\x18\x43ODE_DEPRECATED_ENDPOINT\x10\x03\x12\x19\n\x15\x43ODE_DEPRECATED_PROTO\x10\x04\x12&\n\"CODE_DEPRECATED_SPEC_VALUE_REQUEST\x10\x05\x12\'\n#CODE_DEPRECATED_SPEC_VALUE_RESPONSE\x10\x06\x42Y\n\x17\x61i.nebius.pub.common.v1B\x0cWarningProtoP\x01Z.github.com/nebius/gosdk/proto/nebius/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.common.v1.warning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027ai.nebius.pub.common.v1B\014WarningProtoP\001Z.github.com/nebius/gosdk/proto/nebius/common/v1'
  _globals['_WARNINGS']._serialized_start=52
  _globals['_WARNINGS']._serialized_end=117
  _globals['_WARNING']._serialized_start=120
  _globals['_WARNING']._serialized_end=719
  _globals['_WARNING_TARGET']._serialized_start=399
  _globals['_WARNING_TARGET']._serialized_end=482
  _globals['_WARNING_CODE']._serialized_start=485
  _globals['_WARNING_CODE']._serialized_end=719
# @@protoc_insertion_point(module_scope)
