from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.rpc import status_pb2 as _status_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.common.v1 import operation_pb2 as _operation_pb2
from nebius.api.nebius.common.v1 import operation_service_pb2 as _operation_service_pb2
from nebius.api.nebius.compute.v1 import instance_pb2 as _instance_pb2
from nebius.api.nebius.compute.v1 import operation_service_pb2 as _operation_service_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListInstancesRequest(_message.Message):
    __slots__ = ["parent_id", "page_size", "page_token"]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    parent_id: str
    page_size: int
    page_token: str
    def __init__(self, parent_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class CreateInstanceRequest(_message.Message):
    __slots__ = ["metadata", "spec"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: _instance_pb2.InstanceSpec
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_instance_pb2.InstanceSpec, _Mapping]] = ...) -> None: ...

class UpdateInstanceRequest(_message.Message):
    __slots__ = ["metadata", "spec"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: _instance_pb2.InstanceSpec
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_instance_pb2.InstanceSpec, _Mapping]] = ...) -> None: ...

class DeleteInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListInstancesResponse(_message.Message):
    __slots__ = ["items", "next_page_token"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_instance_pb2.Instance]
    next_page_token: str
    def __init__(self, items: _Optional[_Iterable[_Union[_instance_pb2.Instance, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class StartInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class StopInstanceRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class BatchGetRequest(_message.Message):
    __slots__ = ["instance_ids"]
    INSTANCE_IDS_FIELD_NUMBER: _ClassVar[int]
    instance_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, instance_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class BatchGetResponse(_message.Message):
    __slots__ = ["items"]
    class BatchGetResult(_message.Message):
        __slots__ = ["instance", "error"]
        INSTANCE_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        instance: _instance_pb2.Instance
        error: _status_pb2.Status
        def __init__(self, instance: _Optional[_Union[_instance_pb2.Instance, _Mapping]] = ..., error: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...) -> None: ...
    class ItemsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: BatchGetResponse.BatchGetResult
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[BatchGetResponse.BatchGetResult, _Mapping]] = ...) -> None: ...
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.MessageMap[str, BatchGetResponse.BatchGetResult]
    def __init__(self, items: _Optional[_Mapping[str, BatchGetResponse.BatchGetResult]] = ...) -> None: ...
