# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/capacity/v1/capacity_interval_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.capacity.v1 import capacity_interval_pb2 as nebius_dot_capacity_dot_v1_dot_capacity__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2nebius/capacity/v1/capacity_interval_service.proto\x12\x12nebius.capacity.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a*nebius/capacity/v1/capacity_interval.proto\"M\n\x1aGetCapacityIntervalRequest\x12/\n\x02id\x18\x01 \x01(\tB\x1f\xbaH\x03\xc8\x01\x01\xbaJ\x01\x03\xe2J\x12\n\x10\x63\x61pacityintervalR\x02id\"\xa2\x01\n\x1cListCapacityIntervalsRequest\x12:\n\tparent_id\x18\x01 \x01(\tB\x1d\xbaH\x03\xc8\x01\x01\xe2J\x14\n\x12\x63\x61pacityblockgroupR\x08parentId\x12\'\n\tpage_size\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\xc8\x01(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x83\x01\n\x1dListCapacityIntervalsResponse\x12:\n\x05items\x18\x01 \x03(\x0b\x32$.nebius.capacity.v1.CapacityIntervalR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x83\x02\n\x17\x43\x61pacityIntervalService\x12[\n\x03Get\x12..nebius.capacity.v1.GetCapacityIntervalRequest\x1a$.nebius.capacity.v1.CapacityInterval\x12k\n\x04List\x12\x30.nebius.capacity.v1.ListCapacityIntervalsRequest\x1a\x31.nebius.capacity.v1.ListCapacityIntervalsResponse\x1a\x1e\xbaJ\x1b\x63\x61pacity-blocks.billing-cplBm\n\x19\x61i.nebius.pub.capacity.v1B\x1c\x43\x61pacityIntervalServiceProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/capacity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.capacity.v1.capacity_interval_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.capacity.v1B\034CapacityIntervalServiceProtoP\001Z0github.com/nebius/gosdk/proto/nebius/capacity/v1'
  _GETCAPACITYINTERVALREQUEST.fields_by_name['id']._options = None
  _GETCAPACITYINTERVALREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001\272J\001\003\342J\022\n\020capacityinterval'
  _LISTCAPACITYINTERVALSREQUEST.fields_by_name['parent_id']._options = None
  _LISTCAPACITYINTERVALSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001\342J\024\n\022capacityblockgroup'
  _LISTCAPACITYINTERVALSREQUEST.fields_by_name['page_size']._options = None
  _LISTCAPACITYINTERVALSREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\007\"\005\030\310\001(\000'
  _CAPACITYINTERVALSERVICE._options = None
  _CAPACITYINTERVALSERVICE._serialized_options = b'\272J\033capacity-blocks.billing-cpl'
  _globals['_GETCAPACITYINTERVALREQUEST']._serialized_start=173
  _globals['_GETCAPACITYINTERVALREQUEST']._serialized_end=250
  _globals['_LISTCAPACITYINTERVALSREQUEST']._serialized_start=253
  _globals['_LISTCAPACITYINTERVALSREQUEST']._serialized_end=415
  _globals['_LISTCAPACITYINTERVALSRESPONSE']._serialized_start=418
  _globals['_LISTCAPACITYINTERVALSRESPONSE']._serialized_end=549
  _globals['_CAPACITYINTERVALSERVICE']._serialized_start=552
  _globals['_CAPACITYINTERVALSERVICE']._serialized_end=811
# @@protoc_insertion_point(module_scope)
